<template>
  <div class="workshop">
    <div class="search">
      <div class="search_thing">
        <div class="search_label">车间名称：</div>
        <div class="search_input">
          <el-input size="small" placeholder="请输入" clearable v-model="queryParams.name"
            @keyup.enter.native="refreshTable()"></el-input>
        </div>
      </div>
      <div class="search_thing" style="padding-left: 30px">
        <el-button size="small" @click="refresh()">重 置</el-button>
        <el-button size="small" type="primary" @click="refreshTable()">查 询</el-button>
      </div>
      <el-button size="small" type="primary" style="position: absolute; right: 50px" @click="openAdd('新增')">新
        增</el-button>
    </div>
    <div class="table">
      <lims-table :tableData="tableData" :column="column" :tableLoading="tableLoading" :height="'calc(100vh - 260px)'"
        :page="page" @pagination="pagination"></lims-table>
    </div>
    <!-- 新增/编辑 -->
    <el-dialog :title="title" :visible.sync="addDia" width="500px">
      <el-form :model="addForm" ref="addForm" :rules="addRules" label-position="right" label-width="120px">
        <el-form-item label="车间名称" prop="name">
          <el-input size="small" placeholder="请输入" clearable v-model="addForm.name"></el-input>
        </el-form-item>
      </el-form>
      <span slot="footer" class="dialog-footer">
        <el-button @click="addDia = false">取 消</el-button>
        <el-button :loading="uploading" type="primary" @click="submitProduct('addForm')">确 认</el-button>
      </span>
    </el-dialog>
    <el-dialog :visible.sync="filesDialogVisible" title="附件查看" width="80%">
      <fileList :currentId="id" v-if="filesDialogVisible" />
    </el-dialog>
  </div>
</template>

<script>
import limsTable from "@/components/Table/lims-table.vue";
import fileList from "./components/fileList.vue"
import { selectWorkShop, delWorkShop, addOrUpdateWorkShop } from "@/api/structural/workshop.js"
export default {
  components: {
    limsTable,
    fileList,
  },
  data() {
    return {
      queryParams: {},
      tableData: [],
      column: [
        { label: "车间", prop: "name" },
        {
          dataType: "action",
          fixed: "right",
          label: "操作",
          // handleDelete
          operation: [
            {
              name: "附件",
              type: "text",
              clickFun: (row) => {
                this.handleLookFile(row);
              },
            },
            {
              name: "编辑",
              type: "text",
              clickFun: (row) => {
                this.openAdd('编辑', row);
              },
            },
            {
              name: "删除",
              type: "text",
              clickFun: (row) => {
                this.handleDelete(row);
              },
            },
          ],
        },
      ],
      page: {
        total: 0,
        size: 10,
        current: 0,
      },
      tableLoading: false,
      filesDialogVisible: false,
      id: null,
      addDia: false,
      addRules: {
        name: [{ required: true, message: "请输入车间名称", trigger: "blur" }],
      },
      title: '新增',
      addForm: {},
      uploading: false,
    }
  },
  mounted() {
    this.getList()
  },
  methods: {
    // 查看附件
    handleLookFile(row) {
      this.filesDialogVisible = true;
      this.id = row.id
    },
    // 列表分页
    getList() {
      this.tableLoading = true;
      let param = { ...this.queryParams, ...this.page };
      delete param.total;
      selectWorkShop({ ...param })
        .then((res) => {
          this.tableLoading = false;
          if (res.code === 200) {
            this.tableData = res.data.records;
            this.page.total = res.data.total;
          }
        })
        .catch((err) => {
          this.tableLoading = false;
        });
    },
    pagination({ page, limit }) {
      this.page.current = page;
      this.page.size = limit;
      this.getList();
    },
    refresh() {
      this.queryParams = {};
      this.page.current = 1;
      this.getList();
    },
    refreshTable() {
      this.page.current = 1;
      this.getList();
    },
    // 新增/编辑车间
    openAdd(title, row) {
      this.title = title;
      if (row) {
        this.addForm = row;
      } else {
        this.addForm = {};
      }
      this.addDia = true;
    },
    submitProduct(formName) {
      this.$refs[formName].validate((valid) => {
        if (valid) {
          this.uploading = true;
          if (this.title == "新增") {
            addOrUpdateWorkShop(this.addForm)
              .then((res) => {
                this.uploading = false;
                if (res.code != 200) {
                  return;
                }
                this.$message.success("提交成功");
                this.refresh();
                this.addDia = false;
              })
              .catch((err) => {
                this.uploading = false;
              });
          } else {
            addOrUpdateWorkShop(this.addForm)
              .then((res) => {
                this.uploading = false;
                if (res.code != 200) {
                  return;
                }
                this.$message.success("提交成功");
                this.refresh();
                this.addDia = false;
              })
              .catch((err) => {
                this.uploading = false;
              });
          }
        } else {
          return false;
        }
      });
    },
    handleDelete(row) {
      this.$confirm("是否删除该条数据?", "提示", {
        confirmButtonText: "确定",
        cancelButtonText: "取消",
        type: "warning",
      })
        .then(() => {
          delWorkShop({ id: row.id }).then((res) => {
            console.log('res', res)
            if (res.code == 200) {
              this.$message.success("删除成功");
              this.refresh();
            }
          });
        })
        .catch(() => { });
    },
  }
}
</script>

<style scoped>
.search {
  background-color: #fff;
  height: 80px;
  display: flex;
  align-items: center;
}

.search_thing {
  width: 250px;
  display: flex;
  align-items: center;
}

.search_label {
  width: 90px;
  font-size: 14px;
  text-align: right;
}

.search_input {
  width: calc(100% - 70px);
}

.table {
  padding: 10px;
  padding-top: 0;
}
</style>